==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/es_MX.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "Unknown user" : "Usuario desconocido",
    "New comment …" : "Nuevo comentario ...",
    "Delete comment" : "Borrar comentario",
    "Post" : "Publicar",
    "Cancel" : "Cancelar",
    "Edit comment" : "Editar comentario",
    "[Deleted user]" : "[Usuario borrado]",
    "No comments yet, start the conversation!" : "¡Aún no hay comentarios, inicie la conversación!",
    "More comments …" : "Más comentarios ...",
    "Save" : "Guardar",
    "Allowed characters {count} of {max}" : "Caracteres permitidos {count} de {max}",
    "Error occurred while retrieving comment with id {id}" : "Se presentó un error al recuperar el comentario con Id {id}",
    "Error occurred while updating comment with id {id}" : "Se presentó un error al actualizar el comentario con Id {id}",
    "Error occurred while posting comment" : "Se presentó un error al publicar el comentario",
    "_%n unread comment_::_%n unread comments_" : ["%n comentarios sin leer","%n comentarios sin leer"],
    "Comment" : "Comentario",
    "You commented" : "Usted comentó",
    "%1$s commented" : "%1$s comentó",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Usted comentó en %1$s",
    "You commented on {file}" : "Usted comentó en {file}",
    "%1$s commented on %2$s" : "%1$s comentó en %2$s",
    "{author} commented on {file}" : "{author} comentó en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> de los archivos",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un usuario (ahora) borrado lo mencionó en un commentario en “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un usuario (ahora) borrado lo mencionó en un commentario en “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s lo mencionó en un comentario en “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} lo menciono en un comentario en “{file}”"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/es_MX.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "Unknown user" : "Usuario desconocido",
    "New comment …" : "Comentario nuevo ...",
    "Delete comment" : "Borrar comentario",
    "Post" : "Publicar",
    "Cancel" : "Cancelar",
    "Edit comment" : "Editar comentario",
    "[Deleted user]" : "[Usuario borrado]",
    "No comments yet, start the conversation!" : "¡Aún no hay comentarios, inicia la conversación!",
    "More comments …" : "Más comentarios ...",
    "Save" : "Guardar",
    "Allowed characters {count} of {max}" : "Caracteres permitidos {count} de {max}",
    "Error occurred while retrieving comment with id {id}" : "Se presentó un error al recuperar el comentario con Id {id}",
    "Error occurred while updating comment with id {id}" : "Se presentó un error al actualizar el comentario con Id {id}",
    "Error occurred while posting comment" : "Se presentó un error al publicar el comentario",
    "_%n unread comment_::_%n unread comments_" : ["%n comentarios sin leer","%n comentarios sin leer"],
    "Comment" : "Comentario",
    "You commented" : "Comentaste",
    "%1$s commented" : "%1$s comentó",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Usted comentó en %1$s",
    "You commented on {file}" : "Hiciste un comentario de {file}",
    "%1$s commented on %2$s" : "%1$s comentó en %2$s",
    "{author} commented on {file}" : "{author} comentó en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> de los archivos",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un usuario (ahora) borrado te mencionó en un commentario en “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un usuario (ahora) borrado te mencionó en un commentario en “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s te mencionó en un comentario en “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} te mencionó en un comentario en “{file}”"
},
"nplurals=2; plural=(n != 1);");
